# Parchments

A grid based financial tool for generating easy to use dictionary objects based on time periods.

## Usage

```python
import parchments
from datetime import datetime
import pprint


row_index = (
    ('Debt', 'dollar', 2),
    ('Revenue', 'dollar', 2),
    ('Ratio', 'percentage', 4),
    ('Days', 'int', 0),
    ('Active', 'bool', 0)
)

period_data = [
    200000.00,
    30000.00,
    0.7500,
    22,
    True,
]

other_period_data = [
    120000.00,
    60000.00,
    0.5000,
    14,
    False,
]

my_grid = parchments.Grid(row_index, period_iteration='month')

my_grid.add_period(datetime(2020, 4, 1), period_data)
my_grid.add_period(datetime(2020, 5, 1), other_period_data)

my_grid.add_period(datetime(2021, 4, 1), other_period_data)
my_grid.add_period(datetime(2021, 5, 1), period_data)

my_grid.project_missing()

my_grid_dict = my_grid.as_dict(verbose_only=False)

pprint.pprint(my_grid_dict)
```

## Output

```python
{{'column_data': [{'date': datetime.date(2020, 4, 1),
                  'datetime': datetime.datetime(2020, 4, 1, 0, 0),
                  'iteration': 'month',
                  'key': '20200401',
                  'verbose': 'Apr 2020',
                  'verbose_numeric': '2020-04-01'},
                 {'date': datetime.date(2020, 5, 1),
                  'datetime': datetime.datetime(2020, 5, 1, 0, 0),
                  'iteration': 'month',
                  'key': '20200501',
                  'verbose': 'May 2020',
                  'verbose_numeric': '2020-05-01'},
                 {'date': datetime.date(2020, 6, 1),
                  'datetime': datetime.datetime(2020, 6, 1, 0, 0),
                  'iteration': 'month',
                  'key': '20200601',
                  'verbose': 'Jun 2020',
                  'verbose_numeric': '2020-06-01'},
                 {'date': datetime.date(2020, 7, 1),
                  'datetime': datetime.datetime(2020, 7, 1, 0, 0),
                  'iteration': 'month',
                  'key': '20200701',
                  'verbose': 'Jul 2020',
                  'verbose_numeric': '2020-07-01'},
                 {'date': datetime.date(2020, 8, 1),
                  'datetime': datetime.datetime(2020, 8, 1, 0, 0),
                  'iteration': 'month',
                  'key': '20200801',
                  'verbose': 'Aug 2020',
                  'verbose_numeric': '2020-08-01'},
                 {'date': datetime.date(2020, 9, 1),
                  'datetime': datetime.datetime(2020, 9, 1, 0, 0),
                  'iteration': 'month',
                  'key': '20200901',
                  'verbose': 'Sep 2020',
                  'verbose_numeric': '2020-09-01'},
                 {'date': datetime.date(2020, 10, 1),
                  'datetime': datetime.datetime(2020, 10, 1, 0, 0),
                  'iteration': 'month',
                  'key': '20201001',
                  'verbose': 'Oct 2020',
                  'verbose_numeric': '2020-10-01'},
                 {'date': datetime.date(2020, 11, 1),
                  'datetime': datetime.datetime(2020, 11, 1, 0, 0),
                  'iteration': 'month',
                  'key': '20201101',
                  'verbose': 'Nov 2020',
                  'verbose_numeric': '2020-11-01'},
                 {'date': datetime.date(2020, 12, 1),
                  'datetime': datetime.datetime(2020, 12, 1, 0, 0),
                  'iteration': 'month',
                  'key': '20201201',
                  'verbose': 'Dec 2020',
                  'verbose_numeric': '2020-12-01'},
                 {'date': datetime.date(2021, 1, 1),
                  'datetime': datetime.datetime(2021, 1, 1, 0, 0),
                  'iteration': 'month',
                  'key': '20210101',
                  'verbose': 'Jan 2021',
                  'verbose_numeric': '2021-01-01'},
                 {'date': datetime.date(2021, 2, 1),
                  'datetime': datetime.datetime(2021, 2, 1, 0, 0),
                  'iteration': 'month',
                  'key': '20210201',
                  'verbose': 'Feb 2021',
                  'verbose_numeric': '2021-02-01'},
                 {'date': datetime.date(2021, 3, 1),
                  'datetime': datetime.datetime(2021, 3, 1, 0, 0),
                  'iteration': 'month',
                  'key': '20210301',
                  'verbose': 'Mar 2021',
                  'verbose_numeric': '2021-03-01'},
                 {'date': datetime.date(2021, 4, 1),
                  'datetime': datetime.datetime(2021, 4, 1, 0, 0),
                  'iteration': 'month',
                  'key': '20210401',
                  'verbose': 'Apr 2021',
                  'verbose_numeric': '2021-04-01'},
                 {'date': datetime.date(2021, 5, 1),
                  'datetime': datetime.datetime(2021, 5, 1, 0, 0),
                  'iteration': 'month',
                  'key': '20210501',
                  'verbose': 'May 2021',
                  'verbose_numeric': '2021-05-01'}],
 'row_data': {'Active': [{'actual_number': True,
                          'period_key': '20200401',
                          'value': {'clean': True,
                                    'decimals': 0,
                                    'raw': True,
                                    'type': 'bool',
                                    'verbose': 'True'}},
                         {'actual_number': True,
                          'period_key': '20200501',
                          'value': {'clean': False,
                                    'decimals': 0,
                                    'raw': False,
                                    'type': 'bool',
                                    'verbose': '-'}},
                         {'actual_number': True,
                          'period_key': '20200601',
                          'value': {'clean': False,
                                    'decimals': 0,
                                    'raw': False,
                                    'type': 'bool',
                                    'verbose': '-'}},
                         {'actual_number': True,
                          'period_key': '20200701',
                          'value': {'clean': False,
                                    'decimals': 0,
                                    'raw': False,
                                    'type': 'bool',
                                    'verbose': '-'}},
                         {'actual_number': True,
                          'period_key': '20200801',
                          'value': {'clean': False,
                                    'decimals': 0,
                                    'raw': False,
                                    'type': 'bool',
                                    'verbose': '-'}},
                         {'actual_number': True,
                          'period_key': '20200901',
                          'value': {'clean': False,
                                    'decimals': 0,
                                    'raw': False,
                                    'type': 'bool',
                                    'verbose': '-'}},
                         {'actual_number': True,
                          'period_key': '20201001',
                          'value': {'clean': False,
                                    'decimals': 0,
                                    'raw': False,
                                    'type': 'bool',
                                    'verbose': '-'}},
                         {'actual_number': True,
                          'period_key': '20201101',
                          'value': {'clean': False,
                                    'decimals': 0,
                                    'raw': False,
                                    'type': 'bool',
                                    'verbose': '-'}},
                         {'actual_number': True,
                          'period_key': '20201201',
                          'value': {'clean': False,
                                    'decimals': 0,
                                    'raw': False,
                                    'type': 'bool',
                                    'verbose': '-'}},
                         {'actual_number': True,
                          'period_key': '20210101',
                          'value': {'clean': False,
                                    'decimals': 0,
                                    'raw': False,
                                    'type': 'bool',
                                    'verbose': '-'}},
                         {'actual_number': True,
                          'period_key': '20210201',
                          'value': {'clean': False,
                                    'decimals': 0,
                                    'raw': False,
                                    'type': 'bool',
                                    'verbose': '-'}},
                         {'actual_number': True,
                          'period_key': '20210301',
                          'value': {'clean': False,
                                    'decimals': 0,
                                    'raw': False,
                                    'type': 'bool',
                                    'verbose': '-'}},
                         {'actual_number': True,
                          'period_key': '20210401',
                          'value': {'clean': False,
                                    'decimals': 0,
                                    'raw': False,
                                    'type': 'bool',
                                    'verbose': '-'}},
                         {'actual_number': True,
                          'period_key': '20210501',
                          'value': {'clean': True,
                                    'decimals': 0,
                                    'raw': True,
                                    'type': 'bool',
                                    'verbose': 'True'}},
                         {'sum': {'clean': 2,
                                  'decimals': 0,
                                  'raw': 2,
                                  'type': 'bool',
                                  'verbose': 'True'}},
                         {'average': {'clean': '-',
                                      'decimals': 0,
                                      'raw': '-',
                                      'type': 'bool',
                                      'verbose': 'True'}}],
              'Days': [{'actual_number': True,
                        'growth_amount': {'clean': 0,
                                          'decimals': 0,
                                          'raw': 0,
                                          'type': 'int',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0,
                                               'decimals': 0,
                                               'raw': 0,
                                               'type': 'int',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20200401',
                        'value': {'clean': 22,
                                  'decimals': 0,
                                  'raw': 22,
                                  'type': 'int',
                                  'verbose': '22'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': -8,
                                          'decimals': 0,
                                          'raw': -8,
                                          'type': 'int',
                                          'verbose': '-8'},
                        'growth_percentage': {'clean': -0.36363636363636365,
                                              'decimals': 4,
                                              'raw': -0.36363636363636365,
                                              'type': 'percentage',
                                              'verbose': '-36.3636%'},
                        'over_growth_amount': {'clean': 0,
                                               'decimals': 0,
                                               'raw': 0,
                                               'type': 'int',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20200501',
                        'value': {'clean': 14,
                                  'decimals': 0,
                                  'raw': 14,
                                  'type': 'int',
                                  'verbose': '14'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0,
                                          'decimals': 0,
                                          'raw': 0,
                                          'type': 'int',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0,
                                               'decimals': 0,
                                               'raw': 0,
                                               'type': 'int',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20200601',
                        'value': {'clean': 14,
                                  'decimals': 0,
                                  'raw': 14,
                                  'type': 'int',
                                  'verbose': '14'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0,
                                          'decimals': 0,
                                          'raw': 0,
                                          'type': 'int',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0,
                                               'decimals': 0,
                                               'raw': 0,
                                               'type': 'int',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20200701',
                        'value': {'clean': 14,
                                  'decimals': 0,
                                  'raw': 14,
                                  'type': 'int',
                                  'verbose': '14'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0,
                                          'decimals': 0,
                                          'raw': 0,
                                          'type': 'int',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0,
                                               'decimals': 0,
                                               'raw': 0,
                                               'type': 'int',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20200801',
                        'value': {'clean': 14,
                                  'decimals': 0,
                                  'raw': 14,
                                  'type': 'int',
                                  'verbose': '14'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0,
                                          'decimals': 0,
                                          'raw': 0,
                                          'type': 'int',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0,
                                               'decimals': 0,
                                               'raw': 0,
                                               'type': 'int',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20200901',
                        'value': {'clean': 14,
                                  'decimals': 0,
                                  'raw': 14,
                                  'type': 'int',
                                  'verbose': '14'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0,
                                          'decimals': 0,
                                          'raw': 0,
                                          'type': 'int',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0,
                                               'decimals': 0,
                                               'raw': 0,
                                               'type': 'int',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20201001',
                        'value': {'clean': 14,
                                  'decimals': 0,
                                  'raw': 14,
                                  'type': 'int',
                                  'verbose': '14'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0,
                                          'decimals': 0,
                                          'raw': 0,
                                          'type': 'int',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0,
                                               'decimals': 0,
                                               'raw': 0,
                                               'type': 'int',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20201101',
                        'value': {'clean': 14,
                                  'decimals': 0,
                                  'raw': 14,
                                  'type': 'int',
                                  'verbose': '14'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0,
                                          'decimals': 0,
                                          'raw': 0,
                                          'type': 'int',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0,
                                               'decimals': 0,
                                               'raw': 0,
                                               'type': 'int',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20201201',
                        'value': {'clean': 14,
                                  'decimals': 0,
                                  'raw': 14,
                                  'type': 'int',
                                  'verbose': '14'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0,
                                          'decimals': 0,
                                          'raw': 0,
                                          'type': 'int',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0,
                                               'decimals': 0,
                                               'raw': 0,
                                               'type': 'int',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20210101',
                        'value': {'clean': 14,
                                  'decimals': 0,
                                  'raw': 14,
                                  'type': 'int',
                                  'verbose': '14'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0,
                                          'decimals': 0,
                                          'raw': 0,
                                          'type': 'int',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0,
                                               'decimals': 0,
                                               'raw': 0,
                                               'type': 'int',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20210201',
                        'value': {'clean': 14,
                                  'decimals': 0,
                                  'raw': 14,
                                  'type': 'int',
                                  'verbose': '14'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0,
                                          'decimals': 0,
                                          'raw': 0,
                                          'type': 'int',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0,
                                               'decimals': 0,
                                               'raw': 0,
                                               'type': 'int',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20210301',
                        'value': {'clean': 14,
                                  'decimals': 0,
                                  'raw': 14,
                                  'type': 'int',
                                  'verbose': '14'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0,
                                          'decimals': 0,
                                          'raw': 0,
                                          'type': 'int',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': -8,
                                               'decimals': 0,
                                               'raw': -8,
                                               'type': 'int',
                                               'verbose': '-8'},
                        'over_growth_percentage': {'clean': -0.36363636363636365,
                                                   'decimals': 4,
                                                   'raw': -0.36363636363636365,
                                                   'type': 'percentage',
                                                   'verbose': '-36.3636%'},
                        'period_key': '20210401',
                        'value': {'clean': 14,
                                  'decimals': 0,
                                  'raw': 14,
                                  'type': 'int',
                                  'verbose': '14'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 8,
                                          'decimals': 0,
                                          'raw': 8,
                                          'type': 'int',
                                          'verbose': '8'},
                        'growth_percentage': {'clean': 0.5714285714285714,
                                              'decimals': 4,
                                              'raw': 0.5714285714285714,
                                              'type': 'percentage',
                                              'verbose': '57.1429%'},
                        'over_growth_amount': {'clean': 8,
                                               'decimals': 0,
                                               'raw': 8,
                                               'type': 'int',
                                               'verbose': '8'},
                        'over_growth_percentage': {'clean': 0.5714285714285714,
                                                   'decimals': 4,
                                                   'raw': 0.5714285714285714,
                                                   'type': 'percentage',
                                                   'verbose': '57.1429%'},
                        'period_key': '20210501',
                        'value': {'clean': 22,
                                  'decimals': 0,
                                  'raw': 22,
                                  'type': 'int',
                                  'verbose': '22'}},
                       {'sum': {'clean': 212,
                                'decimals': 0,
                                'raw': 212,
                                'type': 'int',
                                'verbose': '212'}},
                       {'average': {'clean': 15.142857142857142,
                                    'decimals': 0,
                                    'raw': 15.142857142857142,
                                    'type': 'int',
                                    'verbose': '15'}}],
              'Debt': [{'actual_number': True,
                        'growth_amount': {'clean': 0.0,
                                          'decimals': 2,
                                          'raw': 0.0,
                                          'type': 'dollar',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0.0,
                                               'decimals': 2,
                                               'raw': 0.0,
                                               'type': 'dollar',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20200401',
                        'value': {'clean': 200000.0,
                                  'decimals': 2,
                                  'raw': 200000.0,
                                  'type': 'dollar',
                                  'verbose': '$200,000.00'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': -80000.0,
                                          'decimals': 2,
                                          'raw': -80000.0,
                                          'type': 'dollar',
                                          'verbose': '$-80,000.00'},
                        'growth_percentage': {'clean': -0.4,
                                              'decimals': 4,
                                              'raw': -0.4,
                                              'type': 'percentage',
                                              'verbose': '-40.0000%'},
                        'over_growth_amount': {'clean': 0.0,
                                               'decimals': 2,
                                               'raw': 0.0,
                                               'type': 'dollar',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20200501',
                        'value': {'clean': 120000.0,
                                  'decimals': 2,
                                  'raw': 120000.0,
                                  'type': 'dollar',
                                  'verbose': '$120,000.00'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0.0,
                                          'decimals': 2,
                                          'raw': 0.0,
                                          'type': 'dollar',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0.0,
                                               'decimals': 2,
                                               'raw': 0.0,
                                               'type': 'dollar',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20200601',
                        'value': {'clean': 120000.0,
                                  'decimals': 2,
                                  'raw': 120000.0,
                                  'type': 'dollar',
                                  'verbose': '$120,000.00'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0.0,
                                          'decimals': 2,
                                          'raw': 0.0,
                                          'type': 'dollar',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0.0,
                                               'decimals': 2,
                                               'raw': 0.0,
                                               'type': 'dollar',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20200701',
                        'value': {'clean': 120000.0,
                                  'decimals': 2,
                                  'raw': 120000.0,
                                  'type': 'dollar',
                                  'verbose': '$120,000.00'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0.0,
                                          'decimals': 2,
                                          'raw': 0.0,
                                          'type': 'dollar',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0.0,
                                               'decimals': 2,
                                               'raw': 0.0,
                                               'type': 'dollar',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20200801',
                        'value': {'clean': 120000.0,
                                  'decimals': 2,
                                  'raw': 120000.0,
                                  'type': 'dollar',
                                  'verbose': '$120,000.00'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0.0,
                                          'decimals': 2,
                                          'raw': 0.0,
                                          'type': 'dollar',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0.0,
                                               'decimals': 2,
                                               'raw': 0.0,
                                               'type': 'dollar',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20200901',
                        'value': {'clean': 120000.0,
                                  'decimals': 2,
                                  'raw': 120000.0,
                                  'type': 'dollar',
                                  'verbose': '$120,000.00'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0.0,
                                          'decimals': 2,
                                          'raw': 0.0,
                                          'type': 'dollar',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0.0,
                                               'decimals': 2,
                                               'raw': 0.0,
                                               'type': 'dollar',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20201001',
                        'value': {'clean': 120000.0,
                                  'decimals': 2,
                                  'raw': 120000.0,
                                  'type': 'dollar',
                                  'verbose': '$120,000.00'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0.0,
                                          'decimals': 2,
                                          'raw': 0.0,
                                          'type': 'dollar',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0.0,
                                               'decimals': 2,
                                               'raw': 0.0,
                                               'type': 'dollar',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20201101',
                        'value': {'clean': 120000.0,
                                  'decimals': 2,
                                  'raw': 120000.0,
                                  'type': 'dollar',
                                  'verbose': '$120,000.00'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0.0,
                                          'decimals': 2,
                                          'raw': 0.0,
                                          'type': 'dollar',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0.0,
                                               'decimals': 2,
                                               'raw': 0.0,
                                               'type': 'dollar',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20201201',
                        'value': {'clean': 120000.0,
                                  'decimals': 2,
                                  'raw': 120000.0,
                                  'type': 'dollar',
                                  'verbose': '$120,000.00'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0.0,
                                          'decimals': 2,
                                          'raw': 0.0,
                                          'type': 'dollar',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0.0,
                                               'decimals': 2,
                                               'raw': 0.0,
                                               'type': 'dollar',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20210101',
                        'value': {'clean': 120000.0,
                                  'decimals': 2,
                                  'raw': 120000.0,
                                  'type': 'dollar',
                                  'verbose': '$120,000.00'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0.0,
                                          'decimals': 2,
                                          'raw': 0.0,
                                          'type': 'dollar',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0.0,
                                               'decimals': 2,
                                               'raw': 0.0,
                                               'type': 'dollar',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20210201',
                        'value': {'clean': 120000.0,
                                  'decimals': 2,
                                  'raw': 120000.0,
                                  'type': 'dollar',
                                  'verbose': '$120,000.00'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0.0,
                                          'decimals': 2,
                                          'raw': 0.0,
                                          'type': 'dollar',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': 0.0,
                                               'decimals': 2,
                                               'raw': 0.0,
                                               'type': 'dollar',
                                               'verbose': '-'},
                        'over_growth_percentage': {'clean': 0.0,
                                                   'decimals': 4,
                                                   'raw': 0.0,
                                                   'type': 'percentage',
                                                   'verbose': '-'},
                        'period_key': '20210301',
                        'value': {'clean': 120000.0,
                                  'decimals': 2,
                                  'raw': 120000.0,
                                  'type': 'dollar',
                                  'verbose': '$120,000.00'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 0.0,
                                          'decimals': 2,
                                          'raw': 0.0,
                                          'type': 'dollar',
                                          'verbose': '-'},
                        'growth_percentage': {'clean': 0.0,
                                              'decimals': 4,
                                              'raw': 0.0,
                                              'type': 'percentage',
                                              'verbose': '-'},
                        'over_growth_amount': {'clean': -80000.0,
                                               'decimals': 2,
                                               'raw': -80000.0,
                                               'type': 'dollar',
                                               'verbose': '$-80,000.00'},
                        'over_growth_percentage': {'clean': -0.4,
                                                   'decimals': 4,
                                                   'raw': -0.4,
                                                   'type': 'percentage',
                                                   'verbose': '-40.0000%'},
                        'period_key': '20210401',
                        'value': {'clean': 120000.0,
                                  'decimals': 2,
                                  'raw': 120000.0,
                                  'type': 'dollar',
                                  'verbose': '$120,000.00'}},
                       {'actual_number': True,
                        'growth_amount': {'clean': 80000.0,
                                          'decimals': 2,
                                          'raw': 80000.0,
                                          'type': 'dollar',
                                          'verbose': '$80,000.00'},
                        'growth_percentage': {'clean': 0.6666666666666666,
                                              'decimals': 4,
                                              'raw': 0.6666666666666666,
                                              'type': 'percentage',
                                              'verbose': '66.6667%'},
                        'over_growth_amount': {'clean': 80000.0,
                                               'decimals': 2,
                                               'raw': 80000.0,
                                               'type': 'dollar',
                                               'verbose': '$80,000.00'},
                        'over_growth_percentage': {'clean': 0.6666666666666666,
                                                   'decimals': 4,
                                                   'raw': 0.6666666666666666,
                                                   'type': 'percentage',
                                                   'verbose': '66.6667%'},
                        'period_key': '20210501',
                        'value': {'clean': 200000.0,
                                  'decimals': 2,
                                  'raw': 200000.0,
                                  'type': 'dollar',
                                  'verbose': '$200,000.00'}},
                       {'sum': {'clean': 1840000.0,
                                'decimals': 2,
                                'raw': 1840000.0,
                                'type': 'dollar',
                                'verbose': '$1,840,000.00'}},
                       {'average': {'clean': 131428.57142857142,
                                    'decimals': 2,
                                    'raw': 131428.57142857142,
                                    'type': 'dollar',
                                    'verbose': '$131,428.57'}}],
              'Ratio': [{'actual_number': True,
                         'growth_amount': {'clean': 0.0,
                                           'decimals': 4,
                                           'raw': 0.0,
                                           'type': 'percentage',
                                           'verbose': '-'},
                         'growth_percentage': {'clean': 0.0,
                                               'decimals': 4,
                                               'raw': 0.0,
                                               'type': 'percentage',
                                               'verbose': '-'},
                         'over_growth_amount': {'clean': 0.0,
                                                'decimals': 4,
                                                'raw': 0.0,
                                                'type': 'percentage',
                                                'verbose': '-'},
                         'over_growth_percentage': {'clean': 0.0,
                                                    'decimals': 4,
                                                    'raw': 0.0,
                                                    'type': 'percentage',
                                                    'verbose': '-'},
                         'period_key': '20200401',
                         'value': {'clean': 0.75,
                                   'decimals': 4,
                                   'raw': 0.75,
                                   'type': 'percentage',
                                   'verbose': '75.0000%'}},
                        {'actual_number': True,
                         'growth_amount': {'clean': -0.25,
                                           'decimals': 4,
                                           'raw': -0.25,
                                           'type': 'percentage',
                                           'verbose': '-25.0000%'},
                         'growth_percentage': {'clean': -0.3333333333333333,
                                               'decimals': 4,
                                               'raw': -0.3333333333333333,
                                               'type': 'percentage',
                                               'verbose': '-33.3333%'},
                         'over_growth_amount': {'clean': 0.0,
                                                'decimals': 4,
                                                'raw': 0.0,
                                                'type': 'percentage',
                                                'verbose': '-'},
                         'over_growth_percentage': {'clean': 0.0,
                                                    'decimals': 4,
                                                    'raw': 0.0,
                                                    'type': 'percentage',
                                                    'verbose': '-'},
                         'period_key': '20200501',
                         'value': {'clean': 0.5,
                                   'decimals': 4,
                                   'raw': 0.5,
                                   'type': 'percentage',
                                   'verbose': '50.0000%'}},
                        {'actual_number': True,
                         'growth_amount': {'clean': 0.0,
                                           'decimals': 4,
                                           'raw': 0.0,
                                           'type': 'percentage',
                                           'verbose': '-'},
                         'growth_percentage': {'clean': 0.0,
                                               'decimals': 4,
                                               'raw': 0.0,
                                               'type': 'percentage',
                                               'verbose': '-'},
                         'over_growth_amount': {'clean': 0.0,
                                                'decimals': 4,
                                                'raw': 0.0,
                                                'type': 'percentage',
                                                'verbose': '-'},
                         'over_growth_percentage': {'clean': 0.0,
                                                    'decimals': 4,
                                                    'raw': 0.0,
                                                    'type': 'percentage',
                                                    'verbose': '-'},
                         'period_key': '20200601',
                         'value': {'clean': 0.5,
                                   'decimals': 4,
                                   'raw': 0.5,
                                   'type': 'percentage',
                                   'verbose': '50.0000%'}},
                        {'actual_number': True,
                         'growth_amount': {'clean': 0.0,
                                           'decimals': 4,
                                           'raw': 0.0,
                                           'type': 'percentage',
                                           'verbose': '-'},
                         'growth_percentage': {'clean': 0.0,
                                               'decimals': 4,
                                               'raw': 0.0,
                                               'type': 'percentage',
                                               'verbose': '-'},
                         'over_growth_amount': {'clean': 0.0,
                                                'decimals': 4,
                                                'raw': 0.0,
                                                'type': 'percentage',
                                                'verbose': '-'},
                         'over_growth_percentage': {'clean': 0.0,
                                                    'decimals': 4,
                                                    'raw': 0.0,
                                                    'type': 'percentage',
                                                    'verbose': '-'},
                         'period_key': '20200701',
                         'value': {'clean': 0.5,
                                   'decimals': 4,
                                   'raw': 0.5,
                                   'type': 'percentage',
                                   'verbose': '50.0000%'}},
                        {'actual_number': True,
                         'growth_amount': {'clean': 0.0,
                                           'decimals': 4,
                                           'raw': 0.0,
                                           'type': 'percentage',
                                           'verbose': '-'},
                         'growth_percentage': {'clean': 0.0,
                                               'decimals': 4,
                                               'raw': 0.0,
                                               'type': 'percentage',
                                               'verbose': '-'},
                         'over_growth_amount': {'clean': 0.0,
                                                'decimals': 4,
                                                'raw': 0.0,
                                                'type': 'percentage',
                                                'verbose': '-'},
                         'over_growth_percentage': {'clean': 0.0,
                                                    'decimals': 4,
                                                    'raw': 0.0,
                                                    'type': 'percentage',
                                                    'verbose': '-'},
                         'period_key': '20200801',
                         'value': {'clean': 0.5,
                                   'decimals': 4,
                                   'raw': 0.5,
                                   'type': 'percentage',
                                   'verbose': '50.0000%'}},
                        {'actual_number': True,
                         'growth_amount': {'clean': 0.0,
                                           'decimals': 4,
                                           'raw': 0.0,
                                           'type': 'percentage',
                                           'verbose': '-'},
                         'growth_percentage': {'clean': 0.0,
                                               'decimals': 4,
                                               'raw': 0.0,
                                               'type': 'percentage',
                                               'verbose': '-'},
                         'over_growth_amount': {'clean': 0.0,
                                                'decimals': 4,
                                                'raw': 0.0,
                                                'type': 'percentage',
                                                'verbose': '-'},
                         'over_growth_percentage': {'clean': 0.0,
                                                    'decimals': 4,
                                                    'raw': 0.0,
                                                    'type': 'percentage',
                                                    'verbose': '-'},
                         'period_key': '20200901',
                         'value': {'clean': 0.5,
                                   'decimals': 4,
                                   'raw': 0.5,
                                   'type': 'percentage',
                                   'verbose': '50.0000%'}},
                        {'actual_number': True,
                         'growth_amount': {'clean': 0.0,
                                           'decimals': 4,
                                           'raw': 0.0,
                                           'type': 'percentage',
                                           'verbose': '-'},
                         'growth_percentage': {'clean': 0.0,
                                               'decimals': 4,
                                               'raw': 0.0,
                                               'type': 'percentage',
                                               'verbose': '-'},
                         'over_growth_amount': {'clean': 0.0,
                                                'decimals': 4,
                                                'raw': 0.0,
                                                'type': 'percentage',
                                                'verbose': '-'},
                         'over_growth_percentage': {'clean': 0.0,
                                                    'decimals': 4,
                                                    'raw': 0.0,
                                                    'type': 'percentage',
                                                    'verbose': '-'},
                         'period_key': '20201001',
                         'value': {'clean': 0.5,
                                   'decimals': 4,
                                   'raw': 0.5,
                                   'type': 'percentage',
                                   'verbose': '50.0000%'}},
                        {'actual_number': True,
                         'growth_amount': {'clean': 0.0,
                                           'decimals': 4,
                                           'raw': 0.0,
                                           'type': 'percentage',
                                           'verbose': '-'},
                         'growth_percentage': {'clean': 0.0,
                                               'decimals': 4,
                                               'raw': 0.0,
                                               'type': 'percentage',
                                               'verbose': '-'},
                         'over_growth_amount': {'clean': 0.0,
                                                'decimals': 4,
                                                'raw': 0.0,
                                                'type': 'percentage',
                                                'verbose': '-'},
                         'over_growth_percentage': {'clean': 0.0,
                                                    'decimals': 4,
                                                    'raw': 0.0,
                                                    'type': 'percentage',
                                                    'verbose': '-'},
                         'period_key': '20201101',
                         'value': {'clean': 0.5,
                                   'decimals': 4,
                                   'raw': 0.5,
                                   'type': 'percentage',
                                   'verbose': '50.0000%'}},
                        {'actual_number': True,
                         'growth_amount': {'clean': 0.0,
                                           'decimals': 4,
                                           'raw': 0.0,
                                           'type': 'percentage',
                                           'verbose': '-'},
                         'growth_percentage': {'clean': 0.0,
                                               'decimals': 4,
                                               'raw': 0.0,
                                               'type': 'percentage',
                                               'verbose': '-'},
                         'over_growth_amount': {'clean': 0.0,
                                                'decimals': 4,
                                                'raw': 0.0,
                                                'type': 'percentage',
                                                'verbose': '-'},
                         'over_growth_percentage': {'clean': 0.0,
                                                    'decimals': 4,
                                                    'raw': 0.0,
                                                    'type': 'percentage',
                                                    'verbose': '-'},
                         'period_key': '20201201',
                         'value': {'clean': 0.5,
                                   'decimals': 4,
                                   'raw': 0.5,
                                   'type': 'percentage',
                                   'verbose': '50.0000%'}},
                        {'actual_number': True,
                         'growth_amount': {'clean': 0.0,
                                           'decimals': 4,
                                           'raw': 0.0,
                                           'type': 'percentage',
                                           'verbose': '-'},
                         'growth_percentage': {'clean': 0.0,
                                               'decimals': 4,
                                               'raw': 0.0,
                                               'type': 'percentage',
                                               'verbose': '-'},
                         'over_growth_amount': {'clean': 0.0,
                                                'decimals': 4,
                                                'raw': 0.0,
                                                'type': 'percentage',
                                                'verbose': '-'},
                         'over_growth_percentage': {'clean': 0.0,
                                                    'decimals': 4,
                                                    'raw': 0.0,
                                                    'type': 'percentage',
                                                    'verbose': '-'},
                         'period_key': '20210101',
                         'value': {'clean': 0.5,
                                   'decimals': 4,
                                   'raw': 0.5,
                                   'type': 'percentage',
                                   'verbose': '50.0000%'}},
                        {'actual_number': True,
                         'growth_amount': {'clean': 0.0,
                                           'decimals': 4,
                                           'raw': 0.0,
                                           'type': 'percentage',
                                           'verbose': '-'},
                         'growth_percentage': {'clean': 0.0,
                                               'decimals': 4,
                                               'raw': 0.0,
                                               'type': 'percentage',
                                               'verbose': '-'},
                         'over_growth_amount': {'clean': 0.0,
                                                'decimals': 4,
                                                'raw': 0.0,
                                                'type': 'percentage',
                                                'verbose': '-'},
                         'over_growth_percentage': {'clean': 0.0,
                                                    'decimals': 4,
                                                    'raw': 0.0,
                                                    'type': 'percentage',
                                                    'verbose': '-'},
                         'period_key': '20210201',
                         'value': {'clean': 0.5,
                                   'decimals': 4,
                                   'raw': 0.5,
                                   'type': 'percentage',
                                   'verbose': '50.0000%'}},
                        {'actual_number': True,
                         'growth_amount': {'clean': 0.0,
                                           'decimals': 4,
                                           'raw': 0.0,
                                           'type': 'percentage',
                                           'verbose': '-'},
                         'growth_percentage': {'clean': 0.0,
                                               'decimals': 4,
                                               'raw': 0.0,
                                               'type': 'percentage',
                                               'verbose': '-'},
                         'over_growth_amount': {'clean': 0.0,
                                                'decimals': 4,
                                                'raw': 0.0,
                                                'type': 'percentage',
                                                'verbose': '-'},
                         'over_growth_percentage': {'clean': 0.0,
                                                    'decimals': 4,
                                                    'raw': 0.0,
                                                    'type': 'percentage',
                                                    'verbose': '-'},
                         'period_key': '20210301',
                         'value': {'clean': 0.5,
                                   'decimals': 4,
                                   'raw': 0.5,
                                   'type': 'percentage',
                                   'verbose': '50.0000%'}},
                        {'actual_number': True,
                         'growth_amount': {'clean': 0.0,
                                           'decimals': 4,
                                           'raw': 0.0,
                                           'type': 'percentage',
                                           'verbose': '-'},
                         'growth_percentage': {'clean': 0.0,
                                               'decimals': 4,
                                               'raw': 0.0,
                                               'type': 'percentage',
                                               'verbose': '-'},
                         'over_growth_amount': {'clean': -0.25,
                                                'decimals': 4,
                                                'raw': -0.25,
                                                'type': 'percentage',
                                                'verbose': '-25.0000%'},
                         'over_growth_percentage': {'clean': -0.3333333333333333,
                                                    'decimals': 4,
                                                    'raw': -0.3333333333333333,
                                                    'type': 'percentage',
                                                    'verbose': '-33.3333%'},
                         'period_key': '20210401',
                         'value': {'clean': 0.5,
                                   'decimals': 4,
                                   'raw': 0.5,
                                   'type': 'percentage',
                                   'verbose': '50.0000%'}},
                        {'actual_number': True,
                         'growth_amount': {'clean': 0.25,
                                           'decimals': 4,
                                           'raw': 0.25,
                                           'type': 'percentage',
                                           'verbose': '25.0000%'},
                         'growth_percentage': {'clean': 0.5,
                                               'decimals': 4,
                                               'raw': 0.5,
                                               'type': 'percentage',
                                               'verbose': '50.0000%'},
                         'over_growth_amount': {'clean': 0.25,
                                                'decimals': 4,
                                                'raw': 0.25,
                                                'type': 'percentage',
                                                'verbose': '25.0000%'},
                         'over_growth_percentage': {'clean': 0.5,
                                                    'decimals': 4,
                                                    'raw': 0.5,
                                                    'type': 'percentage',
                                                    'verbose': '50.0000%'},
                         'period_key': '20210501',
                         'value': {'clean': 0.75,
                                   'decimals': 4,
                                   'raw': 0.75,
                                   'type': 'percentage',
                                   'verbose': '75.0000%'}},
                        {'sum': {'clean': 7.5,
                                 'decimals': 4,
                                 'raw': 7.5,
                                 'type': 'percentage',
                                 'verbose': '750.0000%'}},
                        {'average': {'clean': 0.5357142857142857,
                                     'decimals': 4,
                                     'raw': 0.5357142857142857,
                                     'type': 'percentage',
                                     'verbose': '53.5714%'}}],
              'Revenue': [{'actual_number': True,
                           'growth_amount': {'clean': 0.0,
                                             'decimals': 2,
                                             'raw': 0.0,
                                             'type': 'dollar',
                                             'verbose': '-'},
                           'growth_percentage': {'clean': 0.0,
                                                 'decimals': 4,
                                                 'raw': 0.0,
                                                 'type': 'percentage',
                                                 'verbose': '-'},
                           'over_growth_amount': {'clean': 0.0,
                                                  'decimals': 2,
                                                  'raw': 0.0,
                                                  'type': 'dollar',
                                                  'verbose': '-'},
                           'over_growth_percentage': {'clean': 0.0,
                                                      'decimals': 4,
                                                      'raw': 0.0,
                                                      'type': 'percentage',
                                                      'verbose': '-'},
                           'period_key': '20200401',
                           'value': {'clean': 30000.0,
                                     'decimals': 2,
                                     'raw': 30000.0,
                                     'type': 'dollar',
                                     'verbose': '$30,000.00'}},
                          {'actual_number': True,
                           'growth_amount': {'clean': 30000.0,
                                             'decimals': 2,
                                             'raw': 30000.0,
                                             'type': 'dollar',
                                             'verbose': '$30,000.00'},
                           'growth_percentage': {'clean': 1.0,
                                                 'decimals': 4,
                                                 'raw': 1.0,
                                                 'type': 'percentage',
                                                 'verbose': '100.0000%'},
                           'over_growth_amount': {'clean': 0.0,
                                                  'decimals': 2,
                                                  'raw': 0.0,
                                                  'type': 'dollar',
                                                  'verbose': '-'},
                           'over_growth_percentage': {'clean': 0.0,
                                                      'decimals': 4,
                                                      'raw': 0.0,
                                                      'type': 'percentage',
                                                      'verbose': '-'},
                           'period_key': '20200501',
                           'value': {'clean': 60000.0,
                                     'decimals': 2,
                                     'raw': 60000.0,
                                     'type': 'dollar',
                                     'verbose': '$60,000.00'}},
                          {'actual_number': True,
                           'growth_amount': {'clean': 0.0,
                                             'decimals': 2,
                                             'raw': 0.0,
                                             'type': 'dollar',
                                             'verbose': '-'},
                           'growth_percentage': {'clean': 0.0,
                                                 'decimals': 4,
                                                 'raw': 0.0,
                                                 'type': 'percentage',
                                                 'verbose': '-'},
                           'over_growth_amount': {'clean': 0.0,
                                                  'decimals': 2,
                                                  'raw': 0.0,
                                                  'type': 'dollar',
                                                  'verbose': '-'},
                           'over_growth_percentage': {'clean': 0.0,
                                                      'decimals': 4,
                                                      'raw': 0.0,
                                                      'type': 'percentage',
                                                      'verbose': '-'},
                           'period_key': '20200601',
                           'value': {'clean': 60000.0,
                                     'decimals': 2,
                                     'raw': 60000.0,
                                     'type': 'dollar',
                                     'verbose': '$60,000.00'}},
                          {'actual_number': True,
                           'growth_amount': {'clean': 0.0,
                                             'decimals': 2,
                                             'raw': 0.0,
                                             'type': 'dollar',
                                             'verbose': '-'},
                           'growth_percentage': {'clean': 0.0,
                                                 'decimals': 4,
                                                 'raw': 0.0,
                                                 'type': 'percentage',
                                                 'verbose': '-'},
                           'over_growth_amount': {'clean': 0.0,
                                                  'decimals': 2,
                                                  'raw': 0.0,
                                                  'type': 'dollar',
                                                  'verbose': '-'},
                           'over_growth_percentage': {'clean': 0.0,
                                                      'decimals': 4,
                                                      'raw': 0.0,
                                                      'type': 'percentage',
                                                      'verbose': '-'},
                           'period_key': '20200701',
                           'value': {'clean': 60000.0,
                                     'decimals': 2,
                                     'raw': 60000.0,
                                     'type': 'dollar',
                                     'verbose': '$60,000.00'}},
                          {'actual_number': True,
                           'growth_amount': {'clean': 0.0,
                                             'decimals': 2,
                                             'raw': 0.0,
                                             'type': 'dollar',
                                             'verbose': '-'},
                           'growth_percentage': {'clean': 0.0,
                                                 'decimals': 4,
                                                 'raw': 0.0,
                                                 'type': 'percentage',
                                                 'verbose': '-'},
                           'over_growth_amount': {'clean': 0.0,
                                                  'decimals': 2,
                                                  'raw': 0.0,
                                                  'type': 'dollar',
                                                  'verbose': '-'},
                           'over_growth_percentage': {'clean': 0.0,
                                                      'decimals': 4,
                                                      'raw': 0.0,
                                                      'type': 'percentage',
                                                      'verbose': '-'},
                           'period_key': '20200801',
                           'value': {'clean': 60000.0,
                                     'decimals': 2,
                                     'raw': 60000.0,
                                     'type': 'dollar',
                                     'verbose': '$60,000.00'}},
                          {'actual_number': True,
                           'growth_amount': {'clean': 0.0,
                                             'decimals': 2,
                                             'raw': 0.0,
                                             'type': 'dollar',
                                             'verbose': '-'},
                           'growth_percentage': {'clean': 0.0,
                                                 'decimals': 4,
                                                 'raw': 0.0,
                                                 'type': 'percentage',
                                                 'verbose': '-'},
                           'over_growth_amount': {'clean': 0.0,
                                                  'decimals': 2,
                                                  'raw': 0.0,
                                                  'type': 'dollar',
                                                  'verbose': '-'},
                           'over_growth_percentage': {'clean': 0.0,
                                                      'decimals': 4,
                                                      'raw': 0.0,
                                                      'type': 'percentage',
                                                      'verbose': '-'},
                           'period_key': '20200901',
                           'value': {'clean': 60000.0,
                                     'decimals': 2,
                                     'raw': 60000.0,
                                     'type': 'dollar',
                                     'verbose': '$60,000.00'}},
                          {'actual_number': True,
                           'growth_amount': {'clean': 0.0,
                                             'decimals': 2,
                                             'raw': 0.0,
                                             'type': 'dollar',
                                             'verbose': '-'},
                           'growth_percentage': {'clean': 0.0,
                                                 'decimals': 4,
                                                 'raw': 0.0,
                                                 'type': 'percentage',
                                                 'verbose': '-'},
                           'over_growth_amount': {'clean': 0.0,
                                                  'decimals': 2,
                                                  'raw': 0.0,
                                                  'type': 'dollar',
                                                  'verbose': '-'},
                           'over_growth_percentage': {'clean': 0.0,
                                                      'decimals': 4,
                                                      'raw': 0.0,
                                                      'type': 'percentage',
                                                      'verbose': '-'},
                           'period_key': '20201001',
                           'value': {'clean': 60000.0,
                                     'decimals': 2,
                                     'raw': 60000.0,
                                     'type': 'dollar',
                                     'verbose': '$60,000.00'}},
                          {'actual_number': True,
                           'growth_amount': {'clean': 0.0,
                                             'decimals': 2,
                                             'raw': 0.0,
                                             'type': 'dollar',
                                             'verbose': '-'},
                           'growth_percentage': {'clean': 0.0,
                                                 'decimals': 4,
                                                 'raw': 0.0,
                                                 'type': 'percentage',
                                                 'verbose': '-'},
                           'over_growth_amount': {'clean': 0.0,
                                                  'decimals': 2,
                                                  'raw': 0.0,
                                                  'type': 'dollar',
                                                  'verbose': '-'},
                           'over_growth_percentage': {'clean': 0.0,
                                                      'decimals': 4,
                                                      'raw': 0.0,
                                                      'type': 'percentage',
                                                      'verbose': '-'},
                           'period_key': '20201101',
                           'value': {'clean': 60000.0,
                                     'decimals': 2,
                                     'raw': 60000.0,
                                     'type': 'dollar',
                                     'verbose': '$60,000.00'}},
                          {'actual_number': True,
                           'growth_amount': {'clean': 0.0,
                                             'decimals': 2,
                                             'raw': 0.0,
                                             'type': 'dollar',
                                             'verbose': '-'},
                           'growth_percentage': {'clean': 0.0,
                                                 'decimals': 4,
                                                 'raw': 0.0,
                                                 'type': 'percentage',
                                                 'verbose': '-'},
                           'over_growth_amount': {'clean': 0.0,
                                                  'decimals': 2,
                                                  'raw': 0.0,
                                                  'type': 'dollar',
                                                  'verbose': '-'},
                           'over_growth_percentage': {'clean': 0.0,
                                                      'decimals': 4,
                                                      'raw': 0.0,
                                                      'type': 'percentage',
                                                      'verbose': '-'},
                           'period_key': '20201201',
                           'value': {'clean': 60000.0,
                                     'decimals': 2,
                                     'raw': 60000.0,
                                     'type': 'dollar',
                                     'verbose': '$60,000.00'}},
                          {'actual_number': True,
                           'growth_amount': {'clean': 0.0,
                                             'decimals': 2,
                                             'raw': 0.0,
                                             'type': 'dollar',
                                             'verbose': '-'},
                           'growth_percentage': {'clean': 0.0,
                                                 'decimals': 4,
                                                 'raw': 0.0,
                                                 'type': 'percentage',
                                                 'verbose': '-'},
                           'over_growth_amount': {'clean': 0.0,
                                                  'decimals': 2,
                                                  'raw': 0.0,
                                                  'type': 'dollar',
                                                  'verbose': '-'},
                           'over_growth_percentage': {'clean': 0.0,
                                                      'decimals': 4,
                                                      'raw': 0.0,
                                                      'type': 'percentage',
                                                      'verbose': '-'},
                           'period_key': '20210101',
                           'value': {'clean': 60000.0,
                                     'decimals': 2,
                                     'raw': 60000.0,
                                     'type': 'dollar',
                                     'verbose': '$60,000.00'}},
                          {'actual_number': True,
                           'growth_amount': {'clean': 0.0,
                                             'decimals': 2,
                                             'raw': 0.0,
                                             'type': 'dollar',
                                             'verbose': '-'},
                           'growth_percentage': {'clean': 0.0,
                                                 'decimals': 4,
                                                 'raw': 0.0,
                                                 'type': 'percentage',
                                                 'verbose': '-'},
                           'over_growth_amount': {'clean': 0.0,
                                                  'decimals': 2,
                                                  'raw': 0.0,
                                                  'type': 'dollar',
                                                  'verbose': '-'},
                           'over_growth_percentage': {'clean': 0.0,
                                                      'decimals': 4,
                                                      'raw': 0.0,
                                                      'type': 'percentage',
                                                      'verbose': '-'},
                           'period_key': '20210201',
                           'value': {'clean': 60000.0,
                                     'decimals': 2,
                                     'raw': 60000.0,
                                     'type': 'dollar',
                                     'verbose': '$60,000.00'}},
                          {'actual_number': True,
                           'growth_amount': {'clean': 0.0,
                                             'decimals': 2,
                                             'raw': 0.0,
                                             'type': 'dollar',
                                             'verbose': '-'},
                           'growth_percentage': {'clean': 0.0,
                                                 'decimals': 4,
                                                 'raw': 0.0,
                                                 'type': 'percentage',
                                                 'verbose': '-'},
                           'over_growth_amount': {'clean': 0.0,
                                                  'decimals': 2,
                                                  'raw': 0.0,
                                                  'type': 'dollar',
                                                  'verbose': '-'},
                           'over_growth_percentage': {'clean': 0.0,
                                                      'decimals': 4,
                                                      'raw': 0.0,
                                                      'type': 'percentage',
                                                      'verbose': '-'},
                           'period_key': '20210301',
                           'value': {'clean': 60000.0,
                                     'decimals': 2,
                                     'raw': 60000.0,
                                     'type': 'dollar',
                                     'verbose': '$60,000.00'}},
                          {'actual_number': True,
                           'growth_amount': {'clean': 0.0,
                                             'decimals': 2,
                                             'raw': 0.0,
                                             'type': 'dollar',
                                             'verbose': '-'},
                           'growth_percentage': {'clean': 0.0,
                                                 'decimals': 4,
                                                 'raw': 0.0,
                                                 'type': 'percentage',
                                                 'verbose': '-'},
                           'over_growth_amount': {'clean': 30000.0,
                                                  'decimals': 2,
                                                  'raw': 30000.0,
                                                  'type': 'dollar',
                                                  'verbose': '$30,000.00'},
                           'over_growth_percentage': {'clean': 1.0,
                                                      'decimals': 4,
                                                      'raw': 1.0,
                                                      'type': 'percentage',
                                                      'verbose': '100.0000%'},
                           'period_key': '20210401',
                           'value': {'clean': 60000.0,
                                     'decimals': 2,
                                     'raw': 60000.0,
                                     'type': 'dollar',
                                     'verbose': '$60,000.00'}},
                          {'actual_number': True,
                           'growth_amount': {'clean': -30000.0,
                                             'decimals': 2,
                                             'raw': -30000.0,
                                             'type': 'dollar',
                                             'verbose': '$-30,000.00'},
                           'growth_percentage': {'clean': -0.5,
                                                 'decimals': 4,
                                                 'raw': -0.5,
                                                 'type': 'percentage',
                                                 'verbose': '-50.0000%'},
                           'over_growth_amount': {'clean': -30000.0,
                                                  'decimals': 2,
                                                  'raw': -30000.0,
                                                  'type': 'dollar',
                                                  'verbose': '$-30,000.00'},
                           'over_growth_percentage': {'clean': -0.5,
                                                      'decimals': 4,
                                                      'raw': -0.5,
                                                      'type': 'percentage',
                                                      'verbose': '-50.0000%'},
                           'period_key': '20210501',
                           'value': {'clean': 30000.0,
                                     'decimals': 2,
                                     'raw': 30000.0,
                                     'type': 'dollar',
                                     'verbose': '$30,000.00'}},
                          {'sum': {'clean': 780000.0,
                                   'decimals': 2,
                                   'raw': 780000.0,
                                   'type': 'dollar',
                                   'verbose': '$780,000.00'}},
                          {'average': {'clean': 55714.28571428572,
                                       'decimals': 2,
                                       'raw': 55714.28571428572,
                                       'type': 'dollar',
                                       'verbose': '$55,714.29'}}]}}
```
